@@ -2,6 +2,7 @@ import csv
 from pathlib import Path
 
 from .enrollments import build_enrollment_data
+from .sftp_sync import set_sftp_credentials, send_files
 from .sections import build_sections_data
 from .students import build_student_data
 from .teachers import build_teacher_data
@@ -12,11 +13,13 @@ __all__ = [
     "build_student_data",
     "build_enrollment_data",
     "build_student_data",
+    "send_files",
+    "set_sftp_credentials",
 ]
 
 
-def build_clever_sheets(oneroster_data: list[dict]) -> dict:
-    teachers_data = build_teacher_data(oneroster_data["users"])
+def build_clever_sheets(oneroster_data: list[dict], gam_user_data: list[dict]) -> dict:
+    teachers_data = build_teacher_data(oneroster_data["users"], gam_user_data)
     sections_data = build_sections_data(
         oneroster_data["enrollments"], oneroster_data["classes"], teachers_data
     )
@@ -41,4 +44,4 @@ def export_clever_sheets(clever_sheets: dict, clever_directory: Path = Path()) -
         with open(file_path, "w", encoding="utf8", newline="") as file:
             writer = csv.DictWriter(file, keys)
             writer.writeheader()
-            writer.writerows(data)
+            writer.writerows(data)
\ No newline at end of file
